===========
📌 Examples
===========

This folder defines a series of example scripts that demonstrate how to use various functionalities of the 
``graph_attention_student`` package and the ``Megan`` graph neural network model.

The examples are split into the following files:

- ``00_basic_usage.ipynb``: A notebook that shows how to set up and train a basic MEGAN model for a graph regression
  task.
- ``01_full_example.ipynb``: A notebook that provides a more comprehensive example, including data splitting, model training, evaluation, and visualization of explanations.
